@@ -9,13 +9,13 @@ setUp () {
 
 test_set_by_user() {
     export VIRTUALENVWRAPPER_LOG_FILE="$WORKON_HOME/hooks.log"
-    source "$test_dir/../virtualenvwrapper.sh"
+    load_wrappers
     assertTrue "Log file was not created" "[ -f $VIRTUALENVWRAPPER_LOG_FILE ]"
 }
 
 test_file_permissions() {
     export VIRTUALENVWRAPPER_LOG_FILE="$WORKON_HOME/hooks.log"
-    source "$test_dir/../virtualenvwrapper.sh"
+    load_wrappers
     perms=$(ls -l "$VIRTUALENVWRAPPER_LOG_FILE" | cut -f1 -d' ')
     #echo $perms
     assertTrue "Log file permissions are wrong: $perms" "echo $perms | grep '^-rw-rw'"
@@ -25,7 +25,7 @@ test_not_set_by_user() {
     unset WORKON_HOME
     unset VIRTUALENVWRAPPER_LOG_FILE
     unset VIRTUALENVWRAPPER_HOOK_DIR
-    source "$test_dir/../virtualenvwrapper.sh"
+    load_wrappers
     assertSame "" "$VIRTUALENVWRAPPER_LOG_FILE"
 }
 
