@@ -21,9 +21,21 @@ setUp () {
 }
 
 test_virtualenvwrapper_script_set() {
-    source "$test_dir/../virtualenvwrapper.sh"
+    load_wrappers
     assertTrue "VIRTUALENVWRAPPER_SCRIPT is not right: $VIRTUALENVWRAPPER_SCRIPT" \
         "echo $VIRTUALENVWRAPPER_SCRIPT | grep -q /virtualenvwrapper.sh"
 }
 
+test_virtualenvwrapper_version() {
+    load_wrappers
+    typeset ver=$(_virtualenvwrapper_version)
+    assertTrue "version is empty" "[ -n $ver ]"
+}
+
+test_virtualenvwrapper_help_shows_version() {
+    load_wrappers
+    typeset pattern="Version: $(_virtualenvwrapper_version)"
+    assertTrue "version not in command output" "virtualenvwrapper | grep \"$pattern\""
+}
+
 . "$test_dir/shunit2"
